@@ -8,6 +8,7 @@
 import io
 import logging
 import random
+import hashlib
 
 import pystan._api  # stanc wrapper
 from pystan._compat import string_types
@@ -19,7 +20,7 @@ logger = logging.getLogger('pystan')
 
 
 def stanc(file=None, charset='utf-8', model_code=None, model_name="anon_model",
-          verbose=False, obsfucate_model_name=False):
+          verbose=False, obfuscate_model_name=True):
     """Translate Stan model specification into C++ code.
 
     Parameters
@@ -47,7 +48,7 @@ def stanc(file=None, charset='utf-8', model_code=None, model_name="anon_model",
         Indicates whether intermediate output should be piped to the
         console. This output may be useful for debugging.
 
-    obsfucate_model_name : boolean, True by default
+    obfuscate_model_name : boolean, True by default
         If False the model name in the generated C++ code will not be made
         unique by the insertion of randomly generated characters.
         Generally it is recommended that this parameter be left as True.
@@ -115,9 +116,16 @@ def stanc(file=None, charset='utf-8', model_code=None, model_name="anon_model",
             model_code = file.read()
 
     # bytes, going into C++ code
-    model_name_bytes = model_name.encode('ascii')
     model_code_bytes = model_code.encode('ascii')
 
+    if obfuscate_model_name:
+        # Make the model name depend on the code.
+        model_name = (
+            model_name + '_' +
+            hashlib.md5(model_code_bytes).hexdigest())
+
+    model_name_bytes = model_name.encode('ascii')
+
     result = pystan._api.stanc(model_code_bytes, model_name_bytes)
     if result['status'] == -1:  # EXCEPTION_RC = -1
         raise ValueError("Error parsing model code:\n{}".format(result['msg']))
@@ -251,7 +259,7 @@ def stan(file=None, model_name="anon_model", model_code=None, fit=None,
 
         - `adapt_engaged` : bool
         - `adapt_gamma` : float, positive, default 0.05
-        - `adapt_delta` : float, between 0 and 1, default 0.65
+        - `adapt_delta` : float, between 0 and 1, default 0.8
         - `adapt_kappa` : float, between default 0.75
         - `adapt_t0`    : float, positive, default 10
 
