@@ -25,6 +25,7 @@ import string
 import sys
 import warnings
 
+import distutils
 from distutils.core import Extension
 
 import Cython
@@ -75,10 +76,13 @@ def _map_parallel(function, args, n_jobs):
     if multiprocessing and int(n_jobs) not in (0, 1):
         if n_jobs == -1:
             n_jobs = None
-        mymap = multiprocessing.Pool(processes=n_jobs).map
+        pool = multiprocessing.Pool(processes=n_jobs)
+        map_result = pool.map(function, args)
+        pool.close()
+        pool.join()
     else:
-        mymap = map
-    return list(mymap(function, args))
+        map_result = list(map(function, args))
+    return map_result
 
 
 # NOTE: StanModel instance stores references to a compiled, uninstantiated
@@ -189,8 +193,8 @@ class StanModel:
     References
     ----------
 
-    The Stan Development Team (2013) _Stan Modeling Language User's
-    Guide and Reference Manual_.  <URL: http://mc-stan.org/>.
+    The Stan Development Team (2013) *Stan Modeling Language User's
+    Guide and Reference Manual*.  <URL: http://mc-stan.org/>.
 
     Examples
     --------
@@ -204,7 +208,7 @@ class StanModel:
     """
     def __init__(self, file=None, charset='utf-8', model_name="anon_model",
                  model_code=None, stanc_ret=None, boost_lib=None,
-                 eigen_lib=None, save_dso=True, verbose=False, obsfucate_model_name=False):
+                 eigen_lib=None, save_dso=True, verbose=False, obfuscate_model_name=True):
 
         if stanc_ret is None:
             stanc_ret = pystan.api.stanc(file=file,
@@ -212,7 +216,7 @@ class StanModel:
                                          model_code=model_code,
                                          model_name=model_name,
                                          verbose=verbose,
-                                         obsfucate_model_name=obsfucate_model_name)
+                                         obfuscate_model_name=obfuscate_model_name)
 
         if not isinstance(stanc_ret, dict):
             raise ValueError("stanc_ret must be an object returned by stanc.")
@@ -226,7 +230,7 @@ class StanModel:
                              "dictionary from stanc.")
         self.model_cppname = stanc_ret['model_cppname']
         self.model_name = stanc_ret['model_name']
-        self.model_code = model_code
+        self.model_code = stanc_ret['model_code']
         self.model_cppcode = stanc_ret['cppcode']
         self.save_dso = save_dso
 
@@ -276,6 +280,7 @@ class StanModel:
             outfile.write(s)
 
         extra_compile_args = ['-O3', '-ftemplate-depth-256']
+        distutils.log.set_verbosity(verbose)
         extension = Extension(name=module_name,
                               language="c++",
                               sources=[pyx_file],
@@ -392,12 +397,12 @@ class StanModel:
             Specifies how initial parameter values are chosen:
             - 0 or '0' initializes all to be zero on the unconstrained support.
             - 'random' generates random initial values. An optional parameter
-                `init_r` controls the range of randomly generated initial values
-                for parameters in terms of their unconstrained support;
+              `init_r` controls the range of randomly generated initial values
+              for parameters in terms of their unconstrained support;
             - list of size equal to the number of chains (`chains`), where the
-                list contains a dict with initial parameter values;
+              list contains a dict with initial parameter values;
             - function returning a dict with initial parameter values. The
-                function may take an optional argument `chain_id`.
+              function may take an optional argument `chain_id`.
 
         sample_file : string, optional
             File name specifying where samples for *all* parameters and other
@@ -418,8 +423,8 @@ class StanModel:
         -------
         optim : dict or None
             Dictionary with components 'par' and 'value' if the optimization is
-            successful. `optim`['par'] is a dictionary of point estimates,
-            indexed by the parameter name. `optim`['value'] stores the value
+            successful. ``optim['par']`` is a dictionary of point estimates,
+            indexed by the parameter name. ``optim['value']`` stores the value
             of the log-posterior (up to an additive constant, the ``lp__`` in
             Stan) corresponding to the point identified by `optim`['par'].
 
@@ -567,9 +572,9 @@ class StanModel:
 
             These are parameters used in Stan with similar names:
 
-            - `adapt_engaged` : bool
+            - `adapt_engaged` : bool, default True
             - `adapt_gamma` : float, positive, default 0.05
-            - `adapt_delta` : float, between 0 and 1, default 0.65
+            - `adapt_delta` : float, between 0 and 1, default 0.8
             - `adapt_kappa` : float, between default 0.75
             - `adapt_t0`    : float, positive, default 10
 
