@@ -1,5 +1,5 @@
-#ifndef __STAN__AGRAD__FWD__MATRIX__LOG__SUM__EXP__HPP__
-#define __STAN__AGRAD__FWD__MATRIX__LOG__SUM__EXP__HPP__
+#ifndef __STAN__AGRAD__FWD__MATRIX__LOG_SUM_EXP_HPP__
+#define __STAN__AGRAD__FWD__MATRIX__LOG_SUM_EXP_HPP__
 
 #include <vector>
 #include <stan/agrad/fwd/fvar.hpp>
@@ -14,7 +14,7 @@ namespace stan{
     // be able to generalize
     template <typename T, int R, int C>
     fvar<T>
-    log_sum_exp(const Eigen::Matrix<T,R,C>& v) {
+    log_sum_exp(const Eigen::Matrix<fvar<T>,R,C>& v) {
       using stan::math::log_sum_exp;
       using std::exp;
       std::vector<T> vals(v.size());
