@@ -8,6 +8,9 @@
 #include <stan/gm/arguments/arg_adapt_delta.hpp>
 #include <stan/gm/arguments/arg_adapt_kappa.hpp>
 #include <stan/gm/arguments/arg_adapt_t0.hpp>
+#include <stan/gm/arguments/arg_adapt_init_buffer.hpp>
+#include <stan/gm/arguments/arg_adapt_term_buffer.hpp>
+#include <stan/gm/arguments/arg_adapt_window.hpp>
 
 namespace stan {
   
@@ -27,6 +30,9 @@ namespace stan {
         _subarguments.push_back(new arg_adapt_delta());
         _subarguments.push_back(new arg_adapt_kappa());
         _subarguments.push_back(new arg_adapt_t0());
+        _subarguments.push_back(new arg_adapt_init_buffer());
+        _subarguments.push_back(new arg_adapt_term_buffer());
+        _subarguments.push_back(new arg_adapt_window());
         
       }
       
