@@ -15,8 +15,8 @@ namespace stan {
         _name = "file";
         _description = "Output file";
         _validity = "Path to existing file";
-        _default = "samples.csv";
-        _default_value = "samples.csv";
+        _default = "output.csv";
+        _default_value = "output.csv";
         _constrained = false;
         _good_value = "good";
         _value = _default_value;
