@@ -39,7 +39,7 @@ namespace stan {
   namespace gm {
 
     void write_stan(std::ostream* s, const char prefix = '\0') {
-      if(!s) return;
+      if (!s) return;
       
       *s << prefix << " stan_version_major = " << stan::MAJOR_VERSION << std::endl;
       *s << prefix << " stan_version_minor = " << stan::MINOR_VERSION << std::endl;
@@ -48,7 +48,7 @@ namespace stan {
     }
     
     void write_model(std::ostream* s, std::string model_name, const char prefix = '\0') {
-      if(!s) return;
+      if (!s) return;
       
       *s << prefix << " model = " << model_name << std::endl;
       
@@ -64,9 +64,10 @@ namespace stan {
                     << "rejected becuase of the following issue:"
                     << std::endl
                     << e.what() << std::endl
-                    << "If this warning occurs sporadically then the sampler is fine,"
+                    << "If this warning occurs sporadically, such as for highly constrained "
+                    << "variable types like covariance matrices, then the sampler is fine,"
                     << std::endl
-                    << "but if this warning occurs often then your model is either severely "
+                    << "but if this warning occurs often then your model may be either severely "
                     << "ill-conditioned or misspecified."
                     << std::endl;
       
@@ -205,33 +206,60 @@ namespace stan {
       return true;
       
     }
-    
-    template<class Sampler>
-    bool init_adapt(stan::mcmc::base_mcmc* sampler, categorical_argument* adapt) {
 
+    template<class Sampler>
+    bool init_adapt(Sampler* sampler, 
+                    const double delta,
+                    const double gamma,
+                    const double kappa, 
+                    const double t0,
+                    const Eigen::VectorXd& cont_params) {
+      const double epsilon = sampler->get_nominal_stepsize();
+      
+      sampler->get_stepsize_adaptation().set_mu(log(10 * epsilon));
+      sampler->get_stepsize_adaptation().set_delta(delta);
+      sampler->get_stepsize_adaptation().set_gamma(gamma);
+      sampler->get_stepsize_adaptation().set_kappa(kappa);
+      sampler->get_stepsize_adaptation().set_t0(t0);
+      
+      sampler->engage_adaptation();
+      
+      try {
+        sampler->z().q = cont_params;
+        sampler->init_stepsize();
+      } catch (std::runtime_error e) {
+        std::cout << e.what() << std::endl;
+        return false;
+      }
+      
+      return true;
+    }
+
+    template<class Sampler>
+    bool init_adapt(stan::mcmc::base_mcmc* sampler, categorical_argument* adapt,
+                    const Eigen::VectorXd& cont_params) {
+      
       double delta = dynamic_cast<real_argument*>(adapt->arg("delta"))->value();
       double gamma = dynamic_cast<real_argument*>(adapt->arg("gamma"))->value();
       double kappa = dynamic_cast<real_argument*>(adapt->arg("kappa"))->value();
       double t0    = dynamic_cast<real_argument*>(adapt->arg("t0"))->value();
       
-      double epsilon = dynamic_cast<Sampler*>(sampler)->get_nominal_stepsize();
-      
       Sampler* s = dynamic_cast<Sampler*>(sampler);
+
+      return init_adapt<Sampler>(s, delta, gamma, kappa, t0, cont_params);
+    }
+    
+    template<class Sampler>
+    bool init_windowed_adapt(stan::mcmc::base_mcmc* sampler, categorical_argument* adapt, 
+                             unsigned int num_warmup, const Eigen::VectorXd& cont_params) {
       
-      s->get_stepsize_adaptation().set_mu(log(10 * epsilon));
-      s->get_stepsize_adaptation().set_delta(delta);
-      s->get_stepsize_adaptation().set_gamma(gamma);
-      s->get_stepsize_adaptation().set_kappa(kappa);
-      s->get_stepsize_adaptation().set_t0(t0);
+      init_adapt<Sampler>(sampler, adapt, cont_params);
       
-      s->engage_adaptation();
+      unsigned int init_buffer = dynamic_cast<u_int_argument*>(adapt->arg("init_buffer"))->value();
+      unsigned int term_buffer = dynamic_cast<u_int_argument*>(adapt->arg("term_buffer"))->value();
+      unsigned int window = dynamic_cast<u_int_argument*>(adapt->arg("window"))->value();
       
-      try {
-        s->init_stepsize();
-      } catch (std::runtime_error e) {
-        std::cout << e.what() << std::endl;
-        return false;
-      }
+      dynamic_cast<Sampler*>(sampler)->set_window_params(num_warmup, init_buffer, term_buffer, window, &std::cout);
       
       return true;
       
@@ -257,6 +285,9 @@ namespace stan {
       
       if (parser.help_printed())
         return err_code;
+
+      parser.print(&std::cout);
+      std::cout << std::endl;
       
       // Identification
       unsigned int id = dynamic_cast<int_argument*>(parser.arg("id"))->value();
@@ -299,39 +330,22 @@ namespace stan {
       data_stream.close();
       
       // Sample output
-      std::string sample_file = dynamic_cast<string_argument*>(
+      std::string output_file = dynamic_cast<string_argument*>(
                                 parser.arg("output")->arg("file"))->value();
-
-      bool append_sample = dynamic_cast<bool_argument*>(
-                           parser.arg("output")->arg("append_sample"))->value();
-      
-      std::ios_base::openmode samples_append_mode
-        = append_sample
-          ? (std::fstream::out | std::fstream::app)
-          : std::fstream::out;
-      
-      std::fstream* sample_stream = 0;
-      if(sample_file != "") {
-        sample_stream = new std::fstream(sample_file.c_str(),
-                                         samples_append_mode);
+      std::fstream* output_stream = 0;
+      if (output_file != "") {
+        output_stream = new std::fstream(output_file.c_str(),
+                                         std::fstream::out);
       }
       
       // Diagnostic output
       std::string diagnostic_file = dynamic_cast<string_argument*>(
                                     parser.arg("output")->arg("diagnostic_file"))->value();
       
-      bool append_diagnostic = dynamic_cast<bool_argument*>(
-                               parser.arg("output")->arg("append_diagnostic"))->value();
-      
-      std::ios_base::openmode diagnostic_append_mode
-        = append_diagnostic
-          ? (std::fstream::out | std::fstream::app)
-          : std::fstream::out;
-      
       std::fstream* diagnostic_stream = 0;
-      if(diagnostic_file != "") {
+      if (diagnostic_file != "") {
         diagnostic_stream = new std::fstream(diagnostic_file.c_str(),
-                                             diagnostic_append_mode);
+                                             std::fstream::out);
       }
       
       // Refresh rate
@@ -344,8 +358,19 @@ namespace stan {
       
       Model model(data_var_context, &std::cout);
       
-      std::vector<double> cont_params(model.num_params_r());
-      std::vector<int> disc_params(model.num_params_i());
+      Eigen::VectorXd cont_params = Eigen::VectorXd::Zero(model.num_params_r());
+
+      if (output_stream) {
+        write_stan(output_stream, '#');
+        write_model(output_stream, model.model_name(), '#');
+        parser.print(output_stream, '#');
+      }
+      
+      if (diagnostic_stream) {
+        write_stan(diagnostic_stream, '#');
+        write_model(diagnostic_stream, model.model_name(), '#');
+        parser.print(diagnostic_stream, '#');
+      }
       
       int num_init_tries = -1;
       
@@ -357,31 +382,28 @@ namespace stan {
         double R = std::fabs(boost::lexical_cast<double>(init));
         
         if (R == 0) {
-        
-          cont_params = std::vector<double>(model.num_params_r(), 0.0);
-          disc_params = std::vector<int>(model.num_params_i(), 0);
+          
+          cont_params.setZero();
           
           double init_log_prob;
-          std::vector<double> init_grad;
+          Eigen::VectorXd init_grad = Eigen::VectorXd::Zero(model.num_params_r());
           
           try {
             init_log_prob 
-              = stan::model::log_prob_grad<true, true>(model,
-                                                       cont_params, disc_params, init_grad,
-                                                       &std::cout);
+              = stan::model::log_prob_grad<true, true>(model, cont_params, init_grad, &std::cout);
           } catch (std::domain_error e) {
-            std::cout << "Rejecting inititialization at zero because of log_prob_grad failure." << std::endl;
+            std::cout << "Rejecting initialization at zero because of log_prob_grad failure." << std::endl;
             return error_codes::OK;
           }
           
           if (!boost::math::isfinite(init_log_prob)) {
-            std::cout << "Rejecting inititialization at zero because of vanishing density." << std::endl;
+            std::cout << "Rejecting initialization at zero because of vanishing density." << std::endl;
             return 0;
           }
           
-          for (size_t i = 0; i < init_grad.size(); ++i) {
+          for (int i = 0; i < init_grad.size(); ++i) {
             if (!boost::math::isfinite(init_grad[i])) {
-              std::cout << "Rejecting inititialization at zero because of divergent gradient." << std::endl;
+              std::cout << "Rejecting initialization at zero because of divergent gradient." << std::endl;
               return 0;
             }
           }
@@ -395,25 +417,22 @@ namespace stan {
           boost::random::uniform_real_distribution<double> >
           init_rng(base_rng, init_range_distribution);
           
-          cont_params = std::vector<double>(model.num_params_r());
-          disc_params = std::vector<int>(model.num_params_i(), 0);
+          cont_params.setZero();
           
           // Random initializations until log_prob is finite
-          std::vector<double> init_grad;
+          Eigen::VectorXd init_grad = Eigen::VectorXd::Zero(model.num_params_r());
           static int MAX_INIT_TRIES = 100;
           
           for (num_init_tries = 1; num_init_tries <= MAX_INIT_TRIES; ++num_init_tries) {
             
-            for (size_t i = 0; i < cont_params.size(); ++i)
-              cont_params[i] = init_rng();
+            for (int i = 0; i < cont_params.size(); ++i)
+              cont_params(i) = init_rng();
             
             // FIXME: allow config vs. std::cout
             double init_log_prob;
             try {
               init_log_prob
-                = stan::model::log_prob_grad<true, true>(model,
-                                                         cont_params, disc_params, init_grad,
-                                                         &std::cout);
+                = stan::model::log_prob_grad<true, true>(model, cont_params, init_grad, &std::cout);
             } catch (std::domain_error e) {
               write_error_msg(&std::cout, e);
               std::cout << "Rejecting proposed initial value with zero density." << std::endl;
@@ -422,8 +441,8 @@ namespace stan {
             
             if (!boost::math::isfinite(init_log_prob))
               continue;
-            for (size_t i = 0; i < init_grad.size(); ++i)
-              if (!boost::math::isfinite(init_grad[i]))
+            for (int i = 0; i < init_grad.size(); ++i)
+              if (!boost::math::isfinite(init_grad(i)))
                 continue;
             break;
             
@@ -455,7 +474,7 @@ namespace stan {
           
           stan::io::dump init_var_context(init_stream);
           init_stream.close();
-          model.transform_inits(init_var_context, disc_params, cont_params);
+          model.transform_inits(init_var_context, cont_params);
         
         } catch (const std::exception& e) {
           std::cerr << "Error during user-specified initialization:"
@@ -466,50 +485,31 @@ namespace stan {
         }
         
         double init_log_prob;
-        std::vector<double> init_grad;
+        Eigen::VectorXd init_grad = Eigen::VectorXd::Zero(model.num_params_r());
         
         try {
         
           init_log_prob
-            = stan::model::log_prob_grad<true, true>(model,
-                                                     cont_params, disc_params, init_grad,
-                                                     &std::cout);
+            = stan::model::log_prob_grad<true, true>(model, cont_params, init_grad, &std::cout);
 
         } catch (std::domain_error e) {
-          std::cout << "Rejecting user-specified inititialization because of log_prob_grad failure." << std::endl;
+          std::cout << "Rejecting user-specified initialization because of log_prob_grad failure." << std::endl;
           return 0;
         }
         
         if (!boost::math::isfinite(init_log_prob)) {
-          std::cout << "Rejecting user-specified inititialization because of vanishing density." << std::endl;
+          std::cout << "Rejecting user-specified initialization because of vanishing density." << std::endl;
           return 0;
         }
         
-        for (size_t i = 0; i < init_grad.size(); ++i) {
+        for (int i = 0; i < init_grad.size(); ++i) {
           if (!boost::math::isfinite(init_grad[i])) {
-            std::cout << "Rejecting user-specified inititialization because of divergent gradient." << std::endl;
+            std::cout << "Rejecting user-specified initialization because of divergent gradient." << std::endl;
             return 0;
-
           }
         }
         
       }
-
-      // Initial output
-      parser.print(&std::cout);
-      std::cout << std::endl;
-      
-      if (!append_sample && sample_stream) {
-        write_stan(sample_stream, '#');
-        write_model(sample_stream, model.model_name(), '#');
-        parser.print(sample_stream, '#');
-      }
-      
-      if (!append_diagnostic && diagnostic_stream) {
-        write_stan(diagnostic_stream, '#');
-        write_model(sample_stream, model.model_name(), '#');
-        parser.print(diagnostic_stream, '#');
-      }
       
       //////////////////////////////////////////////////
       //               Model Diagnostics              //
@@ -517,14 +517,38 @@ namespace stan {
       
       if (parser.arg("method")->arg("diagnose")) {
       
+        std::vector<double> cont_vector(cont_params.size());
+        for (int i = 0; i < cont_params.size(); ++i)
+          cont_vector.at(i) = cont_params(i);
+        std::vector<int> disc_vector;
+        
         list_argument* test = dynamic_cast<list_argument*>
                               (parser.arg("method")->arg("diagnose")->arg("test"));
         
         if (test->value() == "gradient") {
           std::cout << std::endl << "TEST GRADIENT MODE" << std::endl;
-          int num_failed 
-            = stan::model::test_gradients<true,true>(model,cont_params, disc_params);
+
+          double epsilon = dynamic_cast<real_argument*>
+                           (test->arg("gradient")->arg("epsilon"))->value();
+          
+          double error = dynamic_cast<real_argument*>
+                         (test->arg("gradient")->arg("error"))->value();
+          
+          int num_failed
+            = stan::model::test_gradients<true,true>(model,cont_vector, disc_vector, epsilon, error, std::cout);
+          
+          if (output_stream) {
+            num_failed
+              = stan::model::test_gradients<true,true>(model,cont_vector, disc_vector, epsilon, error, *output_stream);
+          }
+          
+          if (diagnostic_stream) {
+            num_failed
+              = stan::model::test_gradients<true,true>(model,cont_vector, disc_vector, epsilon, error, *diagnostic_stream);
+          }
+          
           (void) num_failed; // FIXME: do something with the number failed
+          
           return error_codes::OK;
         }
         
@@ -536,6 +560,11 @@ namespace stan {
       
       if (parser.arg("method")->arg("optimize")) {
         
+        std::vector<double> cont_vector(cont_params.size());
+        for (int i = 0; i < cont_params.size(); ++i)
+          cont_vector.at(i) = cont_params(i);
+        std::vector<int> disc_vector;
+        
         list_argument* algo = dynamic_cast<list_argument*>
                               (parser.arg("method")->arg("optimize")->arg("algorithm"));
 
@@ -545,9 +574,9 @@ namespace stan {
         bool save_iterations = dynamic_cast<bool_argument*>(
                                parser.arg("method")->arg("optimize")->arg("save_iterations"))->value();
 
-        if (sample_stream) {
-          *sample_stream << "lp__,";
-          model.write_csv_header(*sample_stream);
+        if (output_stream) {
+          *output_stream << "lp__,";
+          model.write_csv_header(*output_stream);
         }
 
         double lp(0);
@@ -557,18 +586,25 @@ namespace stan {
                          algo->arg("nesterov")->arg("stepsize"))->value();
           
           
-          stan::optimization::NesterovGradient<Model> ng(model, cont_params, disc_params,
+          stan::optimization::NesterovGradient<Model> ng(model, cont_vector, disc_vector,
                                                          epsilon, &std::cout);
           
           lp = ng.logp();
           
           double lastlp = lp - 1;
           std::cout << "Initial log joint probability = " << lp << std::endl;
+          if (output_stream && save_iterations) {
+            *output_stream << lp << ',';
+            model.write_csv(base_rng, cont_vector, disc_vector,
+                            *output_stream, &std::cout);
+            output_stream->flush();
+          }
+
           int m = 0;
           for (int i = 0; i < num_iterations; i++) {
             lastlp = lp;
             lp = ng.step();
-            ng.params_r(cont_params);
+            ng.params_r(cont_vector);
             if (do_print(i, refresh)) {
               std::cout << "Iteration ";
               std::cout << std::setw(2) << (m + 1) << ". ";
@@ -578,30 +614,39 @@ namespace stan {
               std::cout.flush();
             }
             m++;
-            if (sample_stream && save_iterations) {
-              *sample_stream << lp << ',';
-              model.write_csv(base_rng, cont_params, disc_params, *sample_stream);
-              sample_stream->flush();
+            if (output_stream && save_iterations) {
+              *output_stream << lp << ',';
+              model.write_csv(base_rng, cont_vector, disc_vector,
+                              *output_stream, &std::cout);
+              output_stream->flush();
             }
 
           }
           return_code = error_codes::OK;
         } else if (algo->value() == "newton") {
+          
           std::vector<double> gradient;
           try {
-            lp = model.template log_prob<false, false>(cont_params, disc_params, &std::cout);
+            lp = model.template log_prob<false, false>(cont_vector, disc_vector, &std::cout);
           } catch (std::domain_error e) {
             write_error_msg(&std::cout, e);
             lp = -std::numeric_limits<double>::infinity();
           }
           
-          double lastlp = lp - 1;
           std::cout << "initial log joint probability = " << lp << std::endl;
+          if (output_stream && save_iterations) {
+            *output_stream << lp << ',';
+            model.write_csv(base_rng, cont_vector, disc_vector,
+                            *output_stream, &std::cout);
+            output_stream->flush();
+          }
+
+          double lastlp = lp - 1;
           int m = 0;
           while ((lp - lastlp) / fabs(lp) > 1e-8) {
             
             lastlp = lp;
-            lp = stan::optimization::newton_step(model, cont_params, disc_params);
+            lp = stan::optimization::newton_step(model, cont_vector, disc_vector);
             std::cout << "Iteration ";
             std::cout << std::setw(2) << (m + 1) << ". ";
             std::cout << "Log joint probability = " << std::setw(10) << lp;
@@ -610,15 +655,17 @@ namespace stan {
             std::cout.flush();
             m++;
 
-            if (sample_stream && save_iterations) {
-              *sample_stream << lp << ',';
-              model.write_csv(base_rng, cont_params, disc_params, *sample_stream);
+            if (output_stream && save_iterations) {
+              *output_stream << lp << ',';
+              model.write_csv(base_rng, cont_vector, disc_vector,
+                              *output_stream, &std::cout);
             }
             
           }
           return_code = error_codes::OK;
         } else if (algo->value() == "bfgs") {
-          stan::optimization::BFGSLineSearch<Model> bfgs(model, cont_params, disc_params,
+          
+          stan::optimization::BFGSLineSearch<Model> bfgs(model, cont_vector, disc_vector,
                                                          &std::cout);
           bfgs._opts.alpha0 = dynamic_cast<real_argument*>(
                          algo->arg("bfgs")->arg("init_alpha"))->value();
@@ -633,6 +680,13 @@ namespace stan {
           lp = bfgs.logp();
           
           std::cout << "initial log joint probability = " << lp << std::endl;
+          if (output_stream && save_iterations) {
+            *output_stream << lp << ',';
+            model.write_csv(base_rng, cont_vector, disc_vector,
+                            *output_stream, &std::cout);
+            output_stream->flush();
+          }
+
           int ret = 0;
           
           while (ret == 0) {  
@@ -650,7 +704,7 @@ namespace stan {
             
             ret = bfgs.step();
             lp = bfgs.logp();
-            bfgs.params_r(cont_params);
+            bfgs.params_r(cont_vector);
             
             if (do_print(bfgs.iter_num(), refresh) || ret != 0 || !bfgs.note().empty()) {
               std::cout << " " << std::setw(7) << bfgs.iter_num() << " ";
@@ -664,10 +718,11 @@ namespace stan {
               std::cout << std::endl;
             }
             
-            if (sample_stream && save_iterations) {
-              *sample_stream << lp << ',';
-              model.write_csv(base_rng, cont_params, disc_params, *sample_stream);
-              sample_stream->flush();
+            if (output_stream && save_iterations) {
+              *output_stream << lp << ',';
+              model.write_csv(base_rng, cont_vector, disc_vector,
+                              *output_stream, &std::cout);
+              output_stream->flush();
             }
           }
           
@@ -684,14 +739,15 @@ namespace stan {
           return_code = error_codes::CONFIG;
         }
 
-        if (sample_stream) {
-          *sample_stream << lp << ',';
-          model.write_csv(base_rng, cont_params, disc_params, *sample_stream);
-          sample_stream->flush();
-          sample_stream->close();
-          delete sample_stream;
+        if (output_stream) {
+          *output_stream << lp << ',';
+          model.write_csv(base_rng, cont_vector, disc_vector,
+                          *output_stream, &std::cout);
+          output_stream->flush();
+          output_stream->close();
+          delete output_stream;
         }
-        return 0;
+        return return_code;
       }
         
       //////////////////////////////////////////////////
@@ -700,7 +756,24 @@ namespace stan {
       
       if (parser.arg("method")->arg("sample")) {
         
-        stan::io::mcmc_writer<Model> writer(sample_stream, diagnostic_stream);
+        
+        // Check timing
+        clock_t start_check = clock();
+        
+        Eigen::VectorXd init_grad = Eigen::VectorXd::Zero(model.num_params_r());
+        stan::model::log_prob_grad<true, true>(model, cont_params, init_grad, &std::cout);
+        
+        clock_t end_check = clock();
+        double deltaT = (double)(end_check - start_check) / CLOCKS_PER_SEC;
+        
+        std::cout << std::endl;
+        std::cout << "Gradient evaluation took " << deltaT << " seconds" << std::endl;
+        std::cout << "1000 transitions using 10 leapfrog steps per transition would take "
+                  << 1e4 * deltaT << " seconds." << std::endl;
+        std::cout << "Adjust your expectations accordingly!" << std::endl << std::endl;
+        std::cout << std::endl;
+        
+        stan::io::mcmc_writer<Model> writer(output_stream, diagnostic_stream, &std::cout);
         
         // Sampling parameters
         int num_warmup = dynamic_cast<int_argument*>(
@@ -715,7 +788,7 @@ namespace stan {
         bool save_warmup = dynamic_cast<bool_argument*>(
                            parser.arg("method")->arg("sample")->arg("save_warmup"))->value();
         
-        stan::mcmc::sample s(cont_params, disc_params, 0, 0);
+        stan::mcmc::sample s(cont_params, 0, 0);
         
         double warmDeltaT;
         double sampleDeltaT;
@@ -738,24 +811,21 @@ namespace stan {
         } else if (algo->value() == "hmc") {
           
           int engine_index = 0;
-          list_argument* engine = dynamic_cast<list_argument*>(algo->arg("hmc")->arg("engine"));
-          
+          list_argument* engine 
+            = dynamic_cast<list_argument*>(algo->arg("hmc")->arg("engine"));
           if (engine->value() == "static") {
             engine_index = 0;
-          
           } else if (engine->value() == "nuts") {
             engine_index = 1;
           }
           
           int metric_index = 0;
-          list_argument* metric = dynamic_cast<list_argument*>(algo->arg("hmc")->arg("metric"));
-          
+          list_argument* metric 
+            = dynamic_cast<list_argument*>(algo->arg("hmc")->arg("metric"));
           if (metric->value() == "unit_e") {
             metric_index = 0;
-            
           } else if (metric->value() == "diag_e") {
             metric_index = 1;
-            
           } else if (metric->value() == "dense_e") {
             metric_index = 2;
           }
@@ -766,91 +836,91 @@ namespace stan {
               
             case 0: {
               typedef stan::mcmc::unit_e_static_hmc<Model, rng_t> sampler;
-              sampler_ptr = new sampler(model, base_rng);
+              sampler_ptr = new sampler(model, base_rng, &std::cout, &std::cout);
               if (!init_static_hmc<sampler>(sampler_ptr, algo)) return 0;
               break;
             }
               
             case 1: {        
               typedef stan::mcmc::unit_e_nuts<Model, rng_t> sampler;
-              sampler_ptr = new sampler(model, base_rng);
+              sampler_ptr = new sampler(model, base_rng, &std::cout, &std::cout);
               if (!init_nuts<sampler>(sampler_ptr, algo)) return 0;
               break;
             }
               
             case 10: {
               typedef stan::mcmc::diag_e_static_hmc<Model, rng_t> sampler;
-              sampler_ptr = new sampler(model, base_rng);
+              sampler_ptr = new sampler(model, base_rng, &std::cout, &std::cout);
               if (!init_static_hmc<sampler>(sampler_ptr, algo)) return 0;
               break;
             }
             
             case 11: {
               typedef stan::mcmc::diag_e_nuts<Model, rng_t> sampler;
-              sampler_ptr = new sampler(model, base_rng);
+              sampler_ptr = new sampler(model, base_rng, &std::cout, &std::cout);
               if (!init_nuts<sampler>(sampler_ptr, algo)) return 0;
               break;
             }
             
             case 20: {
               typedef stan::mcmc::dense_e_static_hmc<Model, rng_t> sampler;
-              sampler_ptr = new sampler(model, base_rng);
+              sampler_ptr = new sampler(model, base_rng, &std::cout, &std::cout);
               if (!init_static_hmc<sampler>(sampler_ptr, algo)) return 0;
               break;
             }
             
             case 21: {
               typedef stan::mcmc::dense_e_nuts<Model, rng_t> sampler;
-              sampler_ptr = new sampler(model, base_rng);
+              sampler_ptr = new sampler(model, base_rng, &std::cout, &std::cout);
               if (!init_nuts<sampler>(sampler_ptr, algo)) return 0;
               break;
             }
             
             case 100: {
               typedef stan::mcmc::adapt_unit_e_static_hmc<Model, rng_t> sampler;
-              sampler_ptr = new sampler(model, base_rng);
+              sampler_ptr = new sampler(model, base_rng, &std::cout, &std::cout);
               if (!init_static_hmc<sampler>(sampler_ptr, algo)) return 0;
-              if (!init_adapt<sampler>(sampler_ptr, adapt)) return 0;
+              if (!init_adapt<sampler>(sampler_ptr, adapt, cont_params)) return 0;
               break;
             }
             
             case 101: {
               typedef stan::mcmc::adapt_unit_e_nuts<Model, rng_t> sampler;
-              sampler_ptr = new sampler(model, base_rng);
+              sampler_ptr = new sampler(model, base_rng, &std::cout, &std::cout);
               if (!init_nuts<sampler>(sampler_ptr, algo)) return 0;
-              if (!init_adapt<sampler>(sampler_ptr, adapt)) return 0;
+              if (!init_adapt<sampler>(sampler_ptr, adapt, cont_params)) return 0;
               break;
             }
             
             case 110: {
               typedef stan::mcmc::adapt_diag_e_static_hmc<Model, rng_t> sampler;
-              sampler_ptr = new sampler(model, base_rng, num_warmup);
+              sampler_ptr = new sampler(model, base_rng, &std::cout, &std::cout);
               if (!init_static_hmc<sampler>(sampler_ptr, algo)) return 0;
-              if (!init_adapt<sampler>(sampler_ptr, adapt)) return 0;
+              if (!init_windowed_adapt<sampler>(sampler_ptr, adapt, num_warmup, cont_params)) return 0;
               break;
             }
             
             case 111: {
               typedef stan::mcmc::adapt_diag_e_nuts<Model, rng_t> sampler;
-              sampler_ptr = new sampler(model, base_rng, num_warmup);
+              sampler_ptr = new sampler(model, base_rng, &std::cout, &std::cout);
               if (!init_nuts<sampler>(sampler_ptr, algo)) return 0;
-              if (!init_adapt<sampler>(sampler_ptr, adapt)) return 0;
+              if (!init_windowed_adapt<sampler>(sampler_ptr, adapt, num_warmup, cont_params)) return 0;
               break;
             }
             
             case 120: {
               typedef stan::mcmc::adapt_dense_e_static_hmc<Model, rng_t> sampler;
-              sampler_ptr = new sampler(model, base_rng, num_warmup);
+              sampler_ptr = new sampler(model, base_rng, &std::cout, &std::cout);
               if (!init_static_hmc<sampler>(sampler_ptr, algo)) return 0;
-              if (!init_adapt<sampler>(sampler_ptr, adapt)) return 0;
+              if (!init_windowed_adapt<sampler>(sampler_ptr, adapt, num_warmup, cont_params)) return 0;
               break;
             }
             
             case 121: {
               typedef stan::mcmc::adapt_dense_e_nuts<Model, rng_t> sampler;
-              sampler_ptr = new sampler(model, base_rng, num_warmup);
+              sampler_ptr = new sampler(model, base_rng, &std::cout, &std::cout);
               if (!init_nuts<sampler>(sampler_ptr, algo)) return 0;
-              if (!init_adapt<sampler>(sampler_ptr, adapt)) return 0;
+              if (!init_windowed_adapt<sampler>(sampler_ptr, adapt, num_warmup, cont_params)) return 0;
               break;
             }
             
@@ -862,8 +932,8 @@ namespace stan {
         }
         
         // Headers
-        if (!append_sample) writer.print_sample_names(s, sampler_ptr, model);
-        if (!append_diagnostic) writer.print_diagnostic_names(s, sampler_ptr, model);
+        writer.print_sample_names(s, sampler_ptr, model);
+        writer.print_diagnostic_names(s, sampler_ptr, model);
         
         // Warm-Up
         clock_t start = clock();
@@ -884,10 +954,10 @@ namespace stan {
         // Sampling
         start = clock();
         
-        sample<Model, rng_t>(sampler_ptr, num_warmup, num_samples, num_thin,
-                             refresh, true,
-                             writer,
-                             s, model, base_rng);
+        stan::gm::sample<Model, rng_t>(sampler_ptr, num_warmup, num_samples, num_thin,
+                                       refresh, true,
+                                       writer,
+                                       s, model, base_rng);
         
         end = clock();
         sampleDeltaT = (double)(end - start) / CLOCKS_PER_SEC;
@@ -898,12 +968,12 @@ namespace stan {
         
       }
       
-      if(sample_stream) {
-        sample_stream->close();
-        delete sample_stream;
+      if (output_stream) {
+        output_stream->close();
+        delete output_stream;
       }
         
-      if(diagnostic_stream) {
+      if (diagnostic_stream) {
         diagnostic_stream->close();
         delete diagnostic_stream;
       }
