@@ -172,6 +172,7 @@ add("cumulative_sum", ROW_VECTOR_T, ROW_VECTOR_T);
 add("determinant",DOUBLE_T,MATRIX_T);
 add("diag_matrix",MATRIX_T,VECTOR_T);
 add("diagonal",VECTOR_T,MATRIX_T);
+add_unary("digamma");
 // dims() is polymorphic by size
 for (size_t i = 0; i < 8; ++i) {
   add("dims",expr_type(INT_T,1),expr_type(INT_T,i));
@@ -748,6 +749,7 @@ add("transpose",ROW_VECTOR_T,VECTOR_T);
 add("transpose",VECTOR_T,ROW_VECTOR_T);
 add("transpose",MATRIX_T,MATRIX_T);
 add_unary("trunc");
+add_unary("trigamma");
 for (size_t i = 0; i < vector_types.size(); ++i) 
   for (size_t j = 0; j < vector_types.size(); ++j) 
     for (size_t k = 0; k < vector_types.size(); ++k) {
