@@ -36,7 +36,7 @@ namespace stan {
       
       base_nuts(M &m, BaseRNG& rng, std::ostream* o, std::ostream* e):
       base_hmc<M, P, H, I, BaseRNG>(m, rng, o, e),
-      _depth(0), _max_depth(5), _max_delta(1000)
+      _depth(0), _max_depth(5), _max_delta(1000), _n_divergent(0)
       {};
       
       ~base_nuts() {};
@@ -57,11 +57,11 @@ namespace stan {
       {
         
         // Initialize the algorithm
-        this->_sample_stepsize();
+        this->sample_stepsize();
         
         nuts_util util;
         
-        this->seed(init_sample.cont_params(), init_sample.disc_params());
+        this->seed(init_sample.cont_params());
         
         this->_hamiltonian.sample_p(this->_z, this->_rand_int);
         this->_hamiltonian.init(this->_z);
@@ -88,12 +88,13 @@ namespace stan {
         int n_valid = 0;
         
         this->_depth = 0;
+        this->_n_divergent = 0;
+        
+        util.n_tree = 0;
+        util.sum_prob = 0;
         
         while (util.criterion && (this->_depth <= this->_max_depth) ) {
           
-          util.n_tree = 0;
-          util.sum_prob = 0;
-          
           // Randomly sample a direction in time
           ps_point* z = 0;
           Eigen::VectorXd* rho = 0;
@@ -139,11 +140,11 @@ namespace stan {
           // Check validity of completed tree
           this->_z.ps_point::operator=(z_plus);
           Eigen::VectorXd delta_rho = rho_minus + rho_init + rho_plus;
-          
-          util.criterion = _compute_criterion(z_minus, this->_z, delta_rho);
+
+          util.criterion = compute_criterion(z_minus, this->_z, delta_rho);
           
           ++(this->_depth);
-          
+
         }
         
         --(this->_depth); // Correct for increment at end of loop
@@ -151,36 +152,36 @@ namespace stan {
         double accept_prob = util.sum_prob / static_cast<double>(util.n_tree);
         
         this->_z.ps_point::operator=(z_sample);
-        return sample(this->_z.q, this->_z.r, - this->_z.V, accept_prob);
+        return sample(this->_z.q, - this->_z.V, accept_prob);
         
       }
       
       void write_sampler_param_names(std::ostream& o) {
-        o << "stepsize__,treedepth__,";
+        o << "stepsize__,treedepth__,n_divergent__,";
       }
       
       void write_sampler_params(std::ostream& o) {
-        o << this->_epsilon << "," << this->_depth << ",";
+        o << this->_epsilon << "," << this->_depth << "," << this->_n_divergent << ",";
       }
       
       void get_sampler_param_names(std::vector<std::string>& names) {
         names.push_back("stepsize__");
         names.push_back("treedepth__");
+        names.push_back("n_divergent__");
       }
       
       void get_sampler_params(std::vector<double>& values) {
         values.push_back(this->_epsilon);
         values.push_back(this->_depth);
+        values.push_back(this->_n_divergent);
       }
 
-      
-    protected:
-      
-      virtual bool _compute_criterion(ps_point& start, P& finish, Eigen::VectorXd& rho) = 0;
+      virtual bool compute_criterion(ps_point& start, P& finish, Eigen::VectorXd& rho) = 0;
       
       // Returns number of valid points in the completed subtree
       int build_tree(int depth, Eigen::VectorXd& rho, 
-                     ps_point* z_init, ps_point& z_propose, nuts_util& util)
+                     ps_point* z_init_parent, ps_point& z_propose,
+                     nuts_util& util)
       {
         
         // Base case
@@ -192,13 +193,14 @@ namespace stan {
           
           rho += this->_z.p;
           
-          if (z_init) *z_init = this->_z;
+          if (z_init_parent) *z_init_parent = this->_z;
           z_propose = this->_z;
           
           double h = this->_hamiltonian.H(this->_z); 
           if (boost::math::isnan(h)) h = std::numeric_limits<double>::infinity();
           
           util.criterion = util.log_u + (h - util.H0) < this->_max_delta;
+          if (!util.criterion) ++(this->_n_divergent);
 
           util.sum_prob += stan::math::min(1, std::exp(util.H0 - h));
           util.n_tree += 1;
@@ -210,21 +212,19 @@ namespace stan {
         else 
         {
           
-          Eigen::VectorXd subtree_rho(rho.size()); subtree_rho.setZero();
+          Eigen::VectorXd left_subtree_rho(rho.size()); left_subtree_rho.setZero();
           ps_point z_init(this->_z);
           
-          int n1 = build_tree(depth - 1, subtree_rho, &z_init, z_propose, util);
+          int n1 = build_tree(depth - 1, left_subtree_rho, &z_init, z_propose, util);
 
-          rho += subtree_rho;
+          if (z_init_parent) *z_init_parent = z_init;
           
           if (!util.criterion) return 0;
           
-          subtree_rho.setZero();
+          Eigen::VectorXd right_subtree_rho(rho.size()); right_subtree_rho.setZero();
           ps_point z_propose_right(z_init);
           
-          int n2 = build_tree(depth - 1, subtree_rho, 0, z_propose_right, util);
-          
-          rho += subtree_rho;
+          int n2 = build_tree(depth - 1, right_subtree_rho, 0, z_propose_right, util);
           
           double accept_prob = static_cast<double>(n2) /
                                static_cast<double>(n1 + n2);
@@ -232,7 +232,12 @@ namespace stan {
           if ( util.criterion && (this->_rand_uniform() < accept_prob) )
             z_propose = z_propose_right;
           
-          util.criterion &= _compute_criterion(z_init, this->_z, rho);
+          Eigen::VectorXd& subtree_rho = left_subtree_rho;
+          subtree_rho += right_subtree_rho;
+          
+          rho += subtree_rho;
+          
+          util.criterion &= compute_criterion(z_init, this->_z, subtree_rho);
           
           return n1 + n2;
           
@@ -243,6 +248,8 @@ namespace stan {
       int _depth;
       int _max_depth;
       double _max_delta;
+
+      int _n_divergent;
       
     };
     
