@@ -9,9 +9,9 @@
 #include <stan/math/error_handling/dom_err.hpp>
 #include <stan/prob/constants.hpp>
 #include <stan/prob/traits.hpp>
-#include <stan/agrad/agrad.hpp>
+#include <stan/agrad/rev.hpp>
 #include <stan/meta/traits.hpp>
-#include <stan/agrad/matrix.hpp>
+#include <stan/agrad/rev/matrix.hpp>
 #include <stan/agrad/rev/matrix/to_var.hpp>
 
 #include <stan/math/matrix/add.hpp>
