@@ -4,7 +4,7 @@
 TEST(McmcVarAdaptation, learn_variance) {
   
   const int n = 10;
-  std::vector<double> q(n, 0.0);
+  Eigen::VectorXd q = Eigen::VectorXd::Zero(n);
   Eigen::VectorXd var(Eigen::VectorXd::Zero(n));
   
   const int n_learn = 10;
@@ -12,7 +12,8 @@ TEST(McmcVarAdaptation, learn_variance) {
   Eigen::VectorXd target_var(Eigen::VectorXd::Ones(n));
   target_var *= 1e-3 * 5.0 / (n_learn + 5.0);
   
-  stan::mcmc::var_adaptation adapter(n, 0);
+  stan::mcmc::var_adaptation adapter(n);
+  adapter.set_window_params(50, 0, 0, n_learn);
   
   for (int i = 0; i < n_learn; ++i)
     adapter.learn_variance(var, q);
